import requests
from bs4 import BeautifulSoup
from urllib.parse import urljoin

def search_dcinside(keyword):
    url = f'https://gall.dcinside.com/board/lists/?id=search&page=1&search_pos=&s_type=search_all&s_keyword={keyword}'
    
    # User-Agent를 설정하여 웹 스크래핑 시 차단을 피할 수 있도록 함
    headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36'}
    
    response = requests.get(url, headers=headers)
    
    if response.status_code == 200:
        soup = BeautifulSoup(response.text, 'html.parser')
        
        # 검색 결과를 가져오는 부분에 따라 코드를 수정
        results = soup.select('.gall_tit')
        
        with open('search_results.txt', 'w', encoding='utf-8') as file:
            for result in results:
                title = result.get_text(strip=True)
                
                # 게시물 링크 추출
                post_link = result.find('a')['href']
                
                # 'javascript:;'와 같은 유효하지 않은 URL일 경우 건너뛰기
                if post_link.startswith('javascript:;'):
                    continue
                
                # 게시물 페이지로 이동하여 추가 정보 추출
                full_post_link = urljoin(url, post_link)  # 상대 경로를 절대 경로로 변환
                post_response = requests.get(full_post_link, headers=headers)
                
                if post_response.status_code == 200:
                    post_soup = BeautifulSoup(post_response.text, 'html.parser')
                    
                    # 작성자, 작성시간, 작성아이디, 작성자 IP 등의 정보를 포함하는 부분에 따라 코드를 수정
                    author = post_soup.select_one('.nickname').get_text(strip=True) if post_soup.select_one('.nickname') else 'N/A'
                    timestamp = post_soup.select_one('.gall_date').get_text(strip=True) if post_soup.select_one('.gall_date') else 'N/A'
                    user_id = post_soup.select_one('.user_id').get_text(strip=True) if post_soup.select_one('.user_id') else 'N/A'
                    
                    # 작성자 IP를 가져오는 부분에 따라 코드를 수정
                    user_ip = post_soup.select_one('.user_ip').get_text(strip=True) if post_soup.select_one('.user_ip') else 'N/A'
                    
                    # 게시물 내용을 가져오는 부분에 따라 코드를 수정
                    post_content = post_soup.select_one('.write_div').get_text(strip=True) if post_soup.select_one('.write_div') else 'N/A'
                    
                    # 결과를 파일에 쓰기
                    file.write(f'Title: {title}\nAuthor: {author}\nTimestamp: {timestamp}\nUser ID: {user_id}\nUser IP: {user_ip}\nContent: {post_content}\n---\n')
                    
                else:
                    print(f'Error getting post details: {post_response.status_code}')
                    # 에러 메시지도 파일에 기록
                    file.write(f'Error getting post details: {post_response.status_code}\n---\n')
        print('Search results saved to search_results.txt')
    else:
        print(f'Error: {response.status_code}')

if __name__ == "__main__":
    keyword_to_search = input("검색할 키워드를 입력하세요: ")
    search_dcinside(keyword_to_search)
